-- Get localization
local L = LibStub("AceLocale-3.0"):GetLocale("GarrisonJukeBox")

-- table holding music info (name, file, length)
local musictable = {
	-- Classic
	i1wow = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\wow_main_theme.mp3", 161},
			},
		},
		{
			name = L["TITLE_TIRISFAL"],
			files = {
				{"Sound\\Music\\ZoneMusic\\EvilForest\\DayEvilForest01.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\EvilForest\\DayEvilForest02.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\EvilForest\\DayEvilForest03.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\EvilForest\\NightEvilForest01.mp3", 57},
				{"Sound\\Music\\ZoneMusic\\EvilForest\\NightEvilForest02.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\EvilForest\\NightEvilForest03.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Forest\\DayForest01.mp3", 55},
				{"Sound\\Music\\ZoneMusic\\Forest\\DayForest02.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Forest\\DayForest03.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\Forest\\NightForest01.mp3", 53},
				{"Sound\\Music\\ZoneMusic\\Forest\\NightForest02.mp3", 43},
				{"Sound\\Music\\ZoneMusic\\Forest\\NightForest03.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\Forest\\NightForest04.mp3", 54},
			},
		},
		{
			name = L["TITLE_MOLTENCORE"],
			files = {
				{"Sound\\Music\\Musical Moments\\battle\\battle01.mp3", 48},
			},
		},
		{
			name = L["TITLE_ASHENVALE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest01.mp3", 50},
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest02.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest03.mp3", 235},
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest04.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\EnchantedForest\\EnchantedForest05.mp3", 70},
			},
		},
		{
			name = L["TITLE_DARNASSUS"],
			files = {
				{"Sound\\Music\\CityMusic\\Darnassus\\Darnassus Intro.mp3", 40},
				{"Sound\\Music\\CityMusic\\Darnassus\\Darnassus Walking 1.mp3", 85},
				{"Sound\\Music\\CityMusic\\Darnassus\\Darnassus Walking 2.mp3", 69},
				{"Sound\\Music\\CityMusic\\Darnassus\\Darnassus Walking 3.mp3", 67},
				{"Sound\\Music\\CityMusic\\Darnassus\\Druid Grove.mp3", 45},
				{"Sound\\Music\\CityMusic\\Darnassus\\Warrior Terrace.mp3", 53},
			},
		},
		{
			name = L["TITLE_GNOMERAGON"],
			files = {
				{"Sound\\Music\\CityMusic\\Gnomeragon\\gnomeragon01-zone.mp3", 64},
				{"Sound\\Music\\CityMusic\\Gnomeragon\\gnomeragon02-zone.mp3", 64},
			},
		},
		{
			name = L["TITLE_IRONFORGE"],
			files = {
				{"Sound\\Music\\CityMusic\\Ironforge\\IronForge Intro.mp3", 86},
				{"Sound\\Music\\CityMusic\\Ironforge\\IronForge Walking 01.mp3", 123},
				{"Sound\\Music\\CityMusic\\Ironforge\\IronForge Walking 02.mp3", 50},
				{"Sound\\Music\\CityMusic\\Ironforge\\Ironforge Walking 03 (Glenn).mp3", 81},
				{"Sound\\Music\\CityMusic\\Ironforge\\Ironforge Walking 04.mp3", 70},
				{"Sound\\Music\\CityMusic\\Ironforge\\tinkertownintro_moment.mp3", 52},
			},
		},
		{
			name = L["TITLE_ORGRIMMAR"],
			files = {
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar01-moment.mp3", 69},
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar01-zone.mp3", 68},
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar02-moment.mp3", 62},
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar02-zone.mp3", 62},
				{"Sound\\Music\\CityMusic\\Orgrimmar\\orgrimmar_intro-moment.mp3", 40},
			},
		},
		{
			name = L["TITLE_STORMWIND"],
			files = {
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind01-moment.mp3", 54},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind02-moment.mp3", 35},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind03-moment.mp3", 70},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind04-zone.mp3", 62},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind05-zone.mp3", 61},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind06-zone.mp3", 53},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind07-zone.mp3", 87},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind08-zone.mp3", 77},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind_highSeas-moment.mp3", 133},
				{"Sound\\Music\\CityMusic\\Stormwind\\stormwind_intro-moment.mp3", 66},
			},
		},
		{
			name = L["TITLE_THUNDERBLUFF"],
			files = {
				{"Sound\\Music\\CityMusic\\Thunderbluff\\Thunderbluff Intro.mp3", 46},
				{"Sound\\Music\\CityMusic\\Thunderbluff\\Thunderbluff Walking 01.mp3", 117},
				{"Sound\\Music\\CityMusic\\Thunderbluff\\Thunderbluff Walking 02.mp3", 116},
				{"Sound\\Music\\CityMusic\\Thunderbluff\\Thunderbluff Walking 03.mp3", 121},
			},
		},
		{
			name = L["TITLE_UNDERCITY"],
			files = {
				{"Sound\\Music\\CityMusic\\Undercity\\undercity01-zone.mp3", 67},
				{"Sound\\Music\\CityMusic\\Undercity\\undercity02-zone.mp3", 85},
				{"Sound\\Music\\CityMusic\\Undercity\\undercity03-zone.mp3", 75},
				{"Sound\\Music\\CityMusic\\Undercity\\undercityintro-moment.mp3", 28},
			},
		},
		{
			name = L["TITLE_AHNQIRAJ"],
			files = {
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajInterior1.mp3", 52},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajInterior2.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajInterior3.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajInteriorCenterRoom1.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajInteriorIntroMain.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajKingRoom.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom1.mp3", 23},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom2.mp3", 17},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom3.mp3", 15},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom4.mp3", 19},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom5.mp3", 31},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom6.mp3", 20},
				{"Sound\\Music\\ZoneMusic\\AhnQiraj\\AhnQirajTriangleRoom7.mp3", 17},
			},
		},
		{
			name = L["TITLE_BARRENS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\DayBarrenDry01.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\DayBarrenDry02.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\DayBarrenDry03.mp3", 55},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\NightBarrenDry01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\NightBarrenDry02.mp3", 41},
				{"Sound\\Music\\ZoneMusic\\BarrenDry\\NightBarrenDry03.mp3", 47},
			},
		},
		{
			name = L["TITLE_FELWOOD"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand01.mp3", 54},
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand02.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand03.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand04.mp3", 79},
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand05.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\CursedLand\\CursedLand06.mp3", 74},
			},
		},
		{
			name = L["TITLE_TANARIS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Desert\\DayDesert01.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\Desert\\DayDesert02.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\Desert\\DayDesert03.mp3", 54},
				{"Sound\\Music\\ZoneMusic\\Desert\\NightDesert01.mp3", 77},
				{"Sound\\Music\\ZoneMusic\\Desert\\NightDesert02.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\Desert\\NightDesert03.mp3", 57},
			},
		},
		{
			name = L["TITLE_STRAGLETHORN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Jungle\\DayJungle01.mp3", 46},
				{"Sound\\Music\\ZoneMusic\\Jungle\\DayJungle02.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Jungle\\DayJungle03.mp3", 48},
				{"Sound\\Music\\ZoneMusic\\Jungle\\NightJungle01.mp3", 54},
				{"Sound\\Music\\ZoneMusic\\Jungle\\NightJungle02.mp3", 53},
				{"Sound\\Music\\ZoneMusic\\Jungle\\NightJungle03.mp3", 89},
			},
		},
		{
			name = L["TITLE_WINTERSPRING"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Mountain\\DayMountain01.mp3", 120},
				{"Sound\\Music\\ZoneMusic\\Mountain\\DayMountain02.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Mountain\\DayMountain03.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\Mountain\\NightMountain01.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\Mountain\\NightMountain02.mp3", 63},
				{"Sound\\Music\\ZoneMusic\\Mountain\\NightMountain03.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\Mountain\\NightMountain04.mp3", 64},
			},
		},
		{
			name = L["TITLE_NAXXRAMAS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasAbominationBoss1.mp3", 61},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasAbominationBoss2.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasAbominationWing1.mp3", 61},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasAbominationWing2.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasAbominationWing3.mp3", 61},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasFrostwyrm1.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasFrostwyrm2.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasFrostwyrm3.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasFrostwyrm4.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasHubBase1.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasHubBase2.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasKelThuzad1.mp3", 95},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasKelThuzad2.mp3", 97},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasKelThuzad3.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasPlagueBoss1.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasPlagueWing1.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasPlagueWing2.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasPlagueWing3.mp3", 77},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasSpiderBoss1.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasSpiderBoss2.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasSpiderWing1.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasSpiderWing2.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasSpiderWing3.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking1.mp3", 102},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking2.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking3.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking4.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking5.mp3", 100},
				{"Sound\\Music\\ZoneMusic\\Naxxramas\\NaxxramasWalking6.mp3", 99},
			},
		},
		{
			name = L["TITLE_PLAINS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Plains\\DayPlains01.mp3", 53},
				{"Sound\\Music\\ZoneMusic\\Plains\\DayPlains02.mp3", 76},
				{"Sound\\Music\\ZoneMusic\\Plains\\NightPlains01.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\Plains\\NightPlains02.mp3", 68},
			},
		},
		{
			name = L["TITLE_SWAMPOFSORROWS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\SoggyPlace\\soggyplace-zone1.mp3", 97},
				{"Sound\\Music\\ZoneMusic\\SoggyPlace\\soggyplace-zone2.mp3", 97},
				{"Sound\\Music\\ZoneMusic\\SoggyPlace\\soggyplace-zone3.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\SoggyPlace\\soggyplace-zone4.mp3", 89},
				{"Sound\\Music\\ZoneMusic\\SoggyPlace\\soggyplace-zone5.mp3", 70},
			},
		},
		{
			name = L["TITLE_BURNINGSTEPPES"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Volcanic\\DayVolcanic01.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\Volcanic\\DayVolcanic02.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Volcanic\\NightVolcanic01.mp3", 71},
				{"Sound\\Music\\ZoneMusic\\Volcanic\\NightVolcanic02.mp3", 64},
			},
		},
		{
			name = L["TITLE_ZULAMAN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB10.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB11.mp3", 74},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB12.mp3", 108},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB13.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB14.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_AMB15.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_BTL11.mp3", 136},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_BTL12.mp3", 117},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_BTL13.mp3", 40},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_BTL14.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_BTL15.mp3", 79},
				{"Sound\\Music\\ZoneMusic\\Zulaman\\ZA_zulaman_VCT10.mp3", 80},
			},
		},
	},

	-- The Burning Crusade
	i2bc = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\BC_main_theme.mp3", 226},
			},
		},
		{
			name = L["TITLE_LAMENTOTHIGHBORNE"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\BCCredits_Lament_of_the_Highborne.mp3", 171},
			},
		},
		{
			name = L["TITLE_AZUREMIST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni05.mp3", 191},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni06.mp3", 110},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni07r.mp3", 110},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_DraeneiWalkUni08r.mp3", 99},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni01.mp3", 103},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni02.mp3", 74},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni03.mp3", 150},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni04.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_NagaWalkUni05.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni01.mp3", 49},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_OwlkinWalkUni02.mp3", 45},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni01.mp3", 206},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02.mp3", 124},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni02r.mp3", 129},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03.mp3", 188},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni03r.mp3", 188},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AV_DraeneiWalkUni04.mp3", 158},
			},
		},
		{
			name = L["TITLE_EXODAR"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarIntro01.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni01.mp3", 109},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni02.mp3", 107},
				{"Sound\\Music\\ZoneMusic\\Azuremyst\\AI_ExodarWalkUni03.mp3", 93},
			},
		},
		{
			name = L["TITLE_BLOODMIST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_NagaIntro01.mp3", 31},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_NagaIntro01r.mp3", 25},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni01r.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni02.mp3", 129},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni03.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni04.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\Bloodmyst\\BI_SatyrWalkUni05.mp3", 144},
			},
		},
		{
			name = L["TITLE_BLACKTEMPLE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ArrivalWalkHero01.mp3", 164},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ArrivalWalkUni02.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ArrivalWalkUni03.mp3", 74},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ArrivalWalkUni04.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkHero09.mp3", 74},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni01.mp3", 61},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni02.mp3", 71},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni03.mp3", 78},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni04.mp3", 91},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni05.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni06.mp3", 29},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni07.mp3", 78},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni08.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni10.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_IllidariWalkUni11.mp3", 35},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_KaraborWalkUni01.mp3", 106},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_KaraborWalkUni02.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_KaraborWalkUni03.mp3", 57},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_KaraborWalkUni04.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_PreludeEvent01.mp3", 253},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkHero01.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni02.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni03.mp3", 79},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni04.mp3", 63},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni05.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni06.mp3", 125},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni07.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_ReliquaryWalkUni08.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkHero01.mp3", 131},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni02.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni03.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni04.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni05.mp3", 56},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni06.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni07.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SanctuaryWalkUni08.mp3", 57},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_StormWalkHero02.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_StormWalkUni01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_StormWalkUni03.mp3", 32},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_StormWalkUni04.mp3", 48},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SummitWalkUni01.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SummitWalkUni02.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SummitWalkUni03.mp3", 41},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SummitWalkUni04.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\BlackTemple\\BT_SummitWalkUni05.mp3", 51},
			},
		},
		{
			name = L["TITLE_BLADESEDGE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_DryForestWalkUni01.mp3", 89},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_DryForestWalkUni02.mp3", 127},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_DryForestWalkUni03.mp3", 131},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_GeneralWalkUni01.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_GeneralWalkUni02.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_GeneralWalkUni03.mp3", 158},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_GeneralWalkUni04.mp3", 110},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_GeneralWalkUni05.mp3", 110},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_OgreWalkUni01.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\BladesEdge\\BL_OgreWalkUni02.mp3", 110},
			},
		},
		{
			name = L["TITLE_CAVERNSOFTIME"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_BrazensFlightIntroUni.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk1Uni.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk2Uni.mp3", 120},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk3Uni.mp3", 169},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk4Uni.mp3", 130},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk5Uni.mp3", 151},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk6Uni.mp3", 161},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk7Uni.mp3", 178},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk8Uni.mp3", 140},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_CavernsWalk9Uni.mp3", 161},
			},
		},
		{
			name = L["TITLE_ESCDURNHOLDE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeCellarWalk1Uni.mp3", 104},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeCellarWalk2Uni.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeCellarWalk3Uni.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk1Uni.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk2Uni.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk3Uni.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk4Uni.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk5Uni.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepExtWalk6Uni.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepIntWalk1Uni.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepIntWalk2Uni.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_DurnholdeKeepIntWalk3Uni.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_EscapeDurnIntroUni.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HillsbradExtWalk1Uni.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HillsbradExtWalk2Uni.mp3", 56},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_TarrenMillExtWalk1Uni.mp3", 78},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_TarrenMillExtWalk2Uni.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_TarrenMillExtWalk3Uni.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_ThrallEscapeIntroUni.mp3", 45},
			},
		},
		{
			name = L["TITLE_HYJAL"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalk7Uni.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalk8Uni.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalk9Uni.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni01.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni02.mp3", 48},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni03.mp3", 45},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni04.mp3", 85},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni05.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni06.mp3", 46},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni10.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni11.mp3", 49},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_HyjalExtWalkUni12.mp3", 67},
			},
		},
		{
			name = L["TITLE_BLACKMORASS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassPortalIntro01.mp3", 28},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassWalkUni01.mp3", 108},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassWalkUni02.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassWalkUni03.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassWalkUni04.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\CavernsOfTime\\CT_MorassWalkUni05.mp3", 73},
			},
		},
		{
			name = L["TITLE_EVERSONG"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_BuildingWalkDay01.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_BuildingWalkDay02.mp3", 68},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_BuildingWalkNight01.mp3", 84},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_BuildingWalkNight02.mp3", 83},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkDay01.mp3", 48},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkDay02.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkDay03.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkNight01.mp3", 51},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkNight02.mp3", 83},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_RuinsWalkNight03.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_ScenicIntroNight01.mp3", 97},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_ScortchedWalkDay01.mp3", 116},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_ScortchedWalkDay02.mp3", 103},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_ScortchedWalkNight01.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_ScortchedWalkNight02.mp3", 61},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonIntro01.mp3", 132},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkDay01.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkDay02.mp3", 79},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkDay03.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkNight01.mp3", 177},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkNight02.mp3", 71},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SilvermoonWalkNight03.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkDay01.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkDay02.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkDay03.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkNight01.mp3", 100},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkNight02.mp3", 100},
				{"Sound\\Music\\ZoneMusic\\Eversong\\ES_SunstriderWalkNight03.mp3", 86},
			},
		},
		{
			name = L["TITLE_GHOSTLANDS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_EversongDarkWalkUni01.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_EversongDarkWalkUni02.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_EversongDarkWalkUni03.mp3", 64},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_EversongDarkWalkUni04.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest1WalkDay01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest1WalkDay02.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest1WalkNight01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest2WalkDay01.mp3", 83},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest2WalkNight01.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest2WalkNight02.mp3", 60},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest3WalkDay01.mp3", 154},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest3WalkNight01.mp3", 51},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest3WalkNight02.mp3", 28},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_Forest3WalkNight03.mp3", 44},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ScenicWalkUni01.mp3", 89},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ScenicWalkUni02.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ScenicWalkUni03.mp3", 78},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ShalandisWalkUni01.mp3", 131},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ShalandisWalkUni02.mp3", 104},
				{"Sound\\Music\\ZoneMusic\\Ghostlands\\GL_ShalandisWalkUni03.mp3", 67},
			},
		},
		{
			name = L["TITLE_HELLFIRE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\BL_HE_OgreWalkUni01.mp3", 75},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\BL_HE_OgreWalkUni02.mp3", 110},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_ArmouryIntroUni01.mp3", 14},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_CitadelDemonWalkUni01.mp3", 53},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_CitadelDemonWalkUni02.mp3", 63},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_CitadelIntroUni01.mp3", 19},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_GeneralWalkUni01.mp3", 130},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_GeneralWalkUni02.mp3", 66},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_GeneralWalkUni03.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_GeneralWalkUni04.mp3", 96},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_GeneralWalkUni05.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_PathOfGloryIntroUni01.mp3", 18},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_RampartsWalkUni01.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_RampartsWalkUni02.mp3", 69},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_StairsIntroUni01.mp3", 18},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_WistfulIntroUni01.mp3", 25},
				{"Sound\\Music\\ZoneMusic\\HellfirePeninsula\\HE_WistfulIntroUni02.mp3", 17},
			},
		},
		{
			name = L["TITLE_KARAZHAN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_BackstageWalkUni01.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_BackstageWalkUni02.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_FoyerIntroUni01.mp3", 117},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_FoyerWalkUni01.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_FoyerWalkUni02.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_FoyerWalkUni03.mp3", 124},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_FoyerWalkUni04.mp3", 31},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni01.mp3", 130},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni02.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni03.mp3", 119},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni04.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni05.mp3", 125},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni06.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_GeneralWalkUni07.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_LibraryWalkUni01.mp3", 128},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_LibraryWalkUni02.mp3", 147},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_LibraryWalkUni03.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_LibraryWalkUni04.mp3", 124},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_MalchezarWalkUni01.mp3", 124},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_MalchezarWalkUni02.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_MalchezarWalkUni03.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_OperaHarpsiWalkUni01.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_OperaOrganWalkUni01.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_StableIntroUni01.mp3", 53},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_StableWalkUni01.mp3", 96},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_StableWalkUni02.mp3", 111},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_StableWalkUni03.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_TowerWalkUni01.mp3", 94},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_TowerWalkUni02.mp3", 115},
				{"Sound\\Music\\ZoneMusic\\Karazhan\\KA_TowerWalkUni03.mp3", 127},
			},
		},
		{
			name = L["TITLE_NAGRAND"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_DiamondIntroUni01.mp3", 73},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkDay01.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkDay02.mp3", 100},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkDay03.mp3", 63},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkNight01.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkNight02.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\Nagrand\\NA_GeneralWalkNight03.mp3", 166},
			},
		},
		{
			name = L["TITLE_NETHERSTORM"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni01.mp3", 150},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni02.mp3", 175},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni03.mp3", 178},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni04.mp3", 181},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni05.mp3", 184},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni06.mp3", 192},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni07.mp3", 193},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni08.mp3", 169},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni09.mp3", 199},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_GeneralWalkUni10.mp3", 223},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_MushroomIntroUni01.mp3", 39},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_MushroomIntroUni02.mp3", 33},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_MushroomIntroUni03.mp3", 37},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_NetherplantIntroUni01.mp3", 44},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_NetherplantIntroUni02.mp3", 51},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_NetherplantIntroUni03.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\Netherstorm\\NS_NetherplantIntroUni04.mp3", 45},
			},
		},
		{
			name = L["TITLE_SUNWELL"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_AssemblyChamberWalkUni01.mp3", 82},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_AssemblyChamberWalkUni02.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_FelEnergyWalkUni01.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleDarkWalkUni01.mp3", 139},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleDarkWalkUni02.mp3", 137},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleDarkWalkUni03.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleLightWalkUni01.mp3", 115},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleLightWalkUni02.mp3", 119},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleLightWalkUni03.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleMedWalkUni01.mp3", 117},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleMedWalkUni02.mp3", 126},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_IsleMedWalkUni03.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersArrivalWalkUni01.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersAsylumWalkUni01.mp3", 97},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersAsylumWalkUni02.mp3", 95},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersAsylumWalkUni03.mp3", 65},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersTerraceWalkUni01.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersTerraceWalkUni02.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersTerraceWalkUni03.mp3", 89},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersTerraceWalkUni04.mp3", 91},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_MagistersTerraceWalkUni05.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellArrivalWalkUni01.mp3", 138},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni01.mp3", 85},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni02.mp3", 78},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni03.mp3", 90},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni04.mp3", 91},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni05.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_PlateauSunwellWalkUni06.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_QuelDanasWalkUni01.mp3", 108},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_QuelDanasWalkUni02.mp3", 84},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_SanctumWalkUni01.mp3", 85},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_ShorelAranWalkUni01.mp3", 87},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_SunwellBombingRunUni01.mp3", 259},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_SunwellFlybyUni01.mp3", 57},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_TheWellWalkUni01.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_TheWellWalkUni02.mp3", 95},
				{"Sound\\Music\\ZoneMusic\\Sunwell\\SW_TheWellWalkUni03.mp3", 95},
			},
		},
		{
			name = L["TITLE_SHADOWMOON"],
			files = {
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni02.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni03.mp3", 106},
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni04.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni05.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\ShadowmoonValley\\SV_GeneralWalkUni06.mp3", 67},
			},
		},
		{
			name = L["TITLE_TEMPESTKEEP"],
			files = {
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_11.mp3", 46},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_12.mp3", 96},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_13.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_14.mp3", 88},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_16.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_17.mp3", 62},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_18.mp3", 85},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_19.mp3", 48},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_20.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_22.mp3", 34},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_AMB_23.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_BTL10.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_BTL11.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_BTL13.mp3", 36},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_STG14.mp3", 11},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_STG15.mp3", 11},
				{"Sound\\Music\\ZoneMusic\\TempestKeep\\tk_TempestKeep_STG16.mp3", 11},
			},
		},
		{
			name = L["TITLE_ZANGARMASH"],
			files = {
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_CoilfangWalkUni01.mp3", 133},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_CoilfangWalkUni02.mp3", 99},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_CoilfangWalkUni03.mp3", 109},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni01.mp3", 81},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni02.mp3", 120},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni03.mp3", 59},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni04.mp3", 103},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni05.mp3", 71},
				{"Sound\\Music\\ZoneMusic\\ZangarMarsh\\ZA_GeneralWalkUni06.mp3", 89},
			},
		},
	},
	
	-- Wrath of the Lich King
	i3wotlk = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\GlueScreenMusic\\WotLK_main_title.mp3", 544},
			},
		},
		{
			name = L["TITLE_STORMPEAKS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\StormPeaks\\SP_GeneralWalkB_Day02.mp3", 82},
			},
		},
		{
			name = L["TITLE_DALARAN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni01.mp3", 67},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni02.mp3", 42},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni03.mp3", 70},
				{"Sound\\Music\\ZoneMusic\\Dalaran\\DC_GeneralWalkUni04.mp3", 88},
			},
		},
		{
			name = L["TITLE_ICECROWNGLACIER"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_01.mp3", 58},
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_02.mp3", 56},
				{"Sound\\Music\\ZoneMusic\\IcecrownGlacier\\IC_GeneralIntro_03.mp3", 57},
			},
		},
		{
			name = L["TITLE_CRYSTALSONGFOREST"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni01.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni02.mp3", 98},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni03.mp3", 72},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni04.mp3", 113},
				{"Sound\\Music\\ZoneMusic\\Crystalsong\\CS_CrystalsongWalkUni05.mp3", 107},
			},
		},
		{
			name = L["TITLE_DRAGONBLIGHT"],
			files = {
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_01.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_02.mp3", 93},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_03.mp3", 92},
				{"Sound\\Music\\ZoneMusic\\Dragonblight\\DB_GeneralIntro_04.mp3", 92},
			},
		},
		{
			name = L["TITLE_HOWLINGFJORD"],
			files = {
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni01.mp3", 30},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni02.mp3", 47},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni03.mp3", 52},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni04.mp3", 26},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni05.mp3", 22},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni06.mp3", 41},
				{"Sound\\Music\\ZoneMusic\\HowlingFjord\\HF_DistWalkUni07.mp3", 23},
			},
		},
		{
			name = L["TITLE_SCHOLAZARBASIN"],
			files = {
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay01.mp3", 175},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay02.mp3", 114},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay03.mp3", 105},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay04.mp3", 112},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay05.mp3", 123},
				{"Sound\\Music\\ZoneMusic\\SholazarBasin\\SB_SholazarWalkDay06.mp3", 142},
			},
		},
		{
			name = L["TITLE_ESCAPEFROMARTHAS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_HallsofChase.mp3", 106},
			},
		},
		{
			name = L["TITLE_LADYORLICH"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_LadyortheLich.mp3", 75},
			},
		},
		{
			name = L["TITLE_ICEFORTRESS"],
			files = {
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress.mp3", 133},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress1.mp3", 153},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress2.mp3", 105},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress3.mp3", 80},
				{"Sound\\Music\\ZoneMusic\\IcecrownRaid\\IR_IceFortress4.mp3", 106},
			},
		},
	},
	
	-- Cataclysm
	i4cata = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_Shattering_UU01.mp3", 725},
			},
		},
		{
			name = L["TITLE_NIGHTELVES"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_NightElves_GU01.mp3", 160},
			},
		},
		{
			name = L["TITLE_AFTERMATH"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_Aftermath_UU01.mp3", 125},
			},
		},
		{
			name = L["TITLE_CORRUPTED_DRAGONBLIGHT"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_CorruptedDragonblight_UU01.mp3", 122},
			},
		},
		{
			name = L["TITLE_DRAGONSOUL"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_DragonSoulA_Moment_04.mp3", 60},
				{"Sound\\Music\\cataclysm\\MUS_43_Gunships_Hero_UU01.mp3", 189},
			},
		},
		{
			name = L["TITLE_FANGS_OT_FATHER"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_FangsOfTheFatherA_Hero_UU01.mp3", 121},
			},
		},
		{
			name = L["TITLE_NIGHTWALK"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_NightWalk_UU02.mp3", 60},
			},
		},
		{
			name = L["TITLE_THRALLBATTLE"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_ThrallEarthWarder_UU01.mp3", 62},
			},
		},
		{
			name = L["TITLE_TWILIGHTSHAMMER"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_TwilightsHammer_UU01.mp3", 113},
			},
		},
		{
			name = L["TITLE_WARSHIPS"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_Warships_Hero_01.mp3", 90},
			},
		},
		{
			name = L["TITLE_WELLOFETERNITY"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_WellOfEternity_Hero_UU01.mp3", 84},
			},
		},
		{
			name = L["TITLE_ZINAZSHARI"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_43_ZinAzshari_Hero_UU01.mp3", 177},
			},
		},
		{
			name = L["TITLE_RAGE_OT_FIRELANDS"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_AdventureA_Hero_UU01.mp3", 141},
			},
		},
		{
			name = L["TITLE_ALLIANCE_ONE_HERO"],
			files = {
				{"Sound\\Music\\cataclysm\\MUS_AllianceHero_UU01.mp3", 195},
			},
		},
	},
	
	-- Mists of Pandaria
	i5mop = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_HeartofPandaria_01.mp3", 480},
			},
		},
		{
			name = L["TITLE_WANDERINGISLE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\WanderingIsle\\MUS_50_WanderingIsleB_Hero_UU01.mp3", 135},
			},
		},
		{
			name = L["TITLE_VALLEY4WINDS"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_BalloonRide_Hero_01.mp3", 165},
			},
		},
		{
			name = L["TITLE_SONG_LIULANG"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_SongofLiulang_VOX_Hero_01.mp3", 170},
			},
		},
		{
			name = L["TITLE_SERPENTRACE"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_SerpentRiders_SerpentRace.mp3", 238},
			},
		},
		{
			name = L["TITLE_GINSUVALOR"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_ShadoPan_A_Hero_03.mp3", 172},
			},
		},
		{
			name = L["TITLE_WAYOTMONK"],
			files = {
				{"Sound\\Music\\Pandaria\\MUS_50_Monk_Windwalker_A_01.mp3", 157},
			},
		},
	},
	
	-- Warlords of Draenor
	i6wod = {
		{
			name = L["TITLE_MAIN_THEME"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_ASiegeofWorlds_MainTitle.mp3", 726},
			},
		},
		{
			name = L["TITLE_A_HEROS_SACRIFICE"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_AHerosSacrifice_v1.mp3", 116},
			},
		},
		{
			name = L["TITLE_A_LIGHT_IT_DARKNESS"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_ALightintheDarkness_v1.mp3", 155},
			},
		},
		{
			name = L["TITLE_SPIRES_OF_ARAK"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Arak2_H.mp3", 157},
			},
		},
		{
			name = L["TITLE_DRAENOR_ARMY"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Army_A.mp3", 142},
			},
		},
		{
			name = L["TITLE_DRAENOR_FREEDOM"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_BFreedom_H2.mp3", 107},
			},
		},
		{
			name = L["TITLE_DRAENOR_BLACKROCK"],
			files = {
				{"Sound\\Music\\Draenor\\MUS_60_Blackrock_H.mp3", 188},
			},
		},
	},
	
	-- Warcraft III
	i7events = {
		{
			name = L["TITLE_POWEROTHORDE"],
			files = {
				{"Sound\\Music\\ZoneMusic\\DMF_L70ETC01.mp3", 282},
			},
		},
		{
			name = L["TITLE_FIREFESTIVAL"],
			files = {
				{"Sound\\Music\\WorldEvents\\AllianceFirepole.mp3", 68},
			},
		},
		{
			name = L["TITLE_ARGENTTOURNY"],
			files = {
				{"Sound\\Music\\ZoneMusic\\ArgentTournament\\AT_JoustEvent.mp3", 123},
			},
		},
	},
}

local GJB = LibStub("AceAddon-3.0"):GetAddon("GarrisonJukeBox")
if not GJB then return end
GJB:SetMusicTable(musictable)